OpenLeafElement

Struct OpenLeafElement 

pub struct OpenLeafElement<'element, Configurer: ConfigureElements<ConfigType>, ConfigType> { /* private fields */ }
Handle to a leaf element configuration scope.

When dropped, the element is automatically closed.

Implementations

Source

impl<'element, ConfigType, Configurer: ConfigureElements<ConfigType>> OpenLeafElement<'element, Configurer, ConfigType>

pub fn set_config(&mut self, config: ConfigType)

Sets the configuration for this UI element

pub fn set_leaf_config<LeafConfig>(&mut self, config: LeafConfig)
where Configurer: ConfigureLeafElements<LeafConfig>,

Sets leaf-only configuration for this element.

pub fn close_element(self)

Closes the UI element

It’s not strictly necessary to call this method, the actual logic of closing the element gets executed when the OpenElement gets dropped.